@@ -17,6 +17,7 @@ def sigmoid(x):
 
 
 def accuracy_metric(predictions, labels, meta=None):
+    print(predictions, labels)
     count = 0
     assert len(predictions) == len(labels)
     if predictions.size() != labels.size():
@@ -25,11 +26,11 @@ def accuracy_metric(predictions, labels, meta=None):
             count += prediction == label
     else:
         for prediction, label in zip(predictions, labels):
-            if sigmoid(prediction) >= 0.5:
+            if sigmoid(prediction[1]) >= 0.5:
                 count += label == 1
             else:
                 count += label == 0
-    return count
+    return 100.0 * count / len(labels)
 
 
 def f1_metric(predictions, labels, meta=None):
@@ -74,6 +75,7 @@ def multirc_em(predictions, labels, meta):
 
 def normalize_answer(s):
     """Lower text and remove punctuation, articles and extra whitespace."""
+
     def remove_articles(text):
         return re.sub(r'\b(a|an|the)\b', ' ', text)
 
